bl_info = {
    "name": "Alex Rig Controls",
    "author": "Wayne Dixon",
    "version": (1, 1),
    "blender": (2, 6, 2),
    "api": 45225,
    "location": "View3D > Properties Panel (in pose mode)",
    "description": "Rig Controls for Alex (Horse Rig)",
    "warning": "",
    "wiki_url": "",
    "tracker_url": "",
    "category": "Animation"}


import bpy

fk_legf_l = ["Scapula.L", "Shoulder_FK.L","Humerous_FK.F.L","Forearm_FK.F.L", "Phalanx_FK.F.L","Foot_FK.F.L"]
fk_legf_r = ["Scapula.R", "Shoulder_FK.R","Humerous_FK.F.R","Forearm_FK.F.R", "Phalanx_FK.F.R","Foot_FK.F.R"]
fk_legb_l = ["Hip.L","Femur_FK.B.L","Tibia_FK.B.L","Shin_FK.B.L","Phalanx_FK.B.L","Foot_FK.B.L"]
fk_legb_r = ["Hip.R","Femur_FK.B.R","Tibia_FK.B.R","Shin_FK.B.R","Phalanx_FK.B.R","Foot_FK.B.R"]

ik_legf_l = ["Scapula.L", "Shoulder_IK.L","Humerous_IK.F.L","Forearm_IK.F.L", "Phalanx_IK.F.L","Foot_IK.F.L","Hoof.F.L","FootPivot.F.L","Ankle_IK_bend.F.L"]
ik_legf_r = ["Scapula.R", "Shoulder_IK.R","Humerous_IK.F.R","Forearm_IK.F.R", "Phalanx_IK.F.R","Foot_IK.F.R","Hoof.F.R","FootPivot.F.R","Ankle_IK_bend.F.R"]
ik_legb_l = ["Hip.L","Femur_IK.B.L","Tibia_IK.B.L","Shin_IK.B.L","Phalanx_IK.B.L","Foot_IK.B.L","Hoof.B.L","Femur_target.B.L"]
ik_legb_r = ["Hip.R","Femur_IK.B.R","Tibia_IK.B.R","Shin_IK.B.R","Phalanx_IK.B.R","Foot_IK.B.R","Hoof.B.R","Femur_target.B.R"]

body = ["Neck","Head","Chest","Torso","Pelvis","Tail.001","Tail.002","Tail.003","Tail.004"]


class AlexProperties(bpy.types.Panel):
    bl_space_type = 'VIEW_3D'
    bl_region_type = 'UI'
    bl_label = "Alex Properties"

    @classmethod
    def poll(self, context):
        if context.mode != 'POSE':
            return False
        try:
           ob = context.active_object
           return (ob.name == "Alex_rig" or ob.name == "Alex_proxy")
        except AttributeError:
           return 0

    def draw(self, context):
        pose_bones = context.active_object.pose.bones

        layout = self.layout        
        col = layout.column()

        # IK
        if is_selected(context, fk_legf_l + ik_legf_l):
            col.label(text="Front Left:")
            col.prop(pose_bones["Hoof.F.L"], '["IK"]', text="IK Front.L", slider=True)
            col.prop(pose_bones["Scapula.L"], '["Isolate"]', text="Isolate Front.L", slider=True)
        if is_selected(context, fk_legf_r + ik_legf_r):
            col.label(text="Front Right:")
            col.prop(pose_bones["Hoof.F.R"], '["IK"]', text="IK Front.R", slider=True)
            col.prop(pose_bones["Scapula.R"], '["Isolate"]', text="Isolate Front.R  ", slider=True)
        if is_selected(context, fk_legb_l + ik_legb_l):
            col.label(text="Back Left:")
            col.prop(pose_bones["Hoof.B.L"], '["IK"]', text="IK Back.L", slider=True)
            col.prop(pose_bones["Hip.L"], '["Isolate"]', text="Isolate Back.L", slider=True)
        if is_selected(context, fk_legb_r + ik_legb_r):
            col.label(text="Back Right:")
            col.prop(pose_bones["Hoof.B.R"], '["IK"]', text="IK Back.R", slider=True)
            col.prop(pose_bones["Hip.R"], '["Isolate"]', text="Isolate Back.R", slider=True)

        #Isolate Rotation Body
        
        if is_selected(context, body):
           col.label(text="Isolate Rotation:")
           col.prop(pose_bones["Head"], '["Isolate"]', text="Head", slider=True)
       
           col.prop(pose_bones["Neck"], '["Isolate"]', text="Neck", slider=True)
       
           col.prop(pose_bones["Tail.001"], '["Isolate"]', text="Tail", slider=True)    
           
           
       

       

class AlexLayers(bpy.types.Panel):
    bl_space_type = 'VIEW_3D'
    bl_region_type = 'UI'
    bl_label = "Alex Layers"

    @classmethod
    def poll(self, context):
        if context.mode != 'POSE':
            return False
        try:
           ob = context.active_object
           return (ob.name == "Alex_rig" or ob.name == "Alex_proxy")
        except AttributeError:
           return 0

    def draw(self, context):
        pose_bones = context.active_object.pose.bones

        layout = self.layout        
        col = layout.column()
        row = col.row(align=True)
        
        try:
            selected_bones = [bone.name for bone in context.selected_pose_bones]
            selected_bones += [context.active_pose_bone.name]
        except (AttributeError, TypeError):
            return
        
        
        def is_selected(names):
            # Returns whether any of the named bones are selected.
            if type(names) == list:
                for name in names:
                    if name in selected_bones:
                        return True
            elif names in selected_bones:
                return True
            return False
        
         #Xray 
        ob = context.active_object
        
        
        
        
        row = col.row(align=True)
        row.prop(ob, "show_x_ray", text="X-Ray", toggle=True)
        
        
        # Layers
              
        body = col.row()
        body.label(text="Body:")
        body.prop(context.active_object.data, "layers", index=3, toggle=True, text="Main")
        body.prop(context.active_object.data, "layers", index=0, toggle=True, text="Root")

        head = col.row()
        head.label(text="Head:")
        head.prop(context.active_object.data, "layers", index=1, toggle=True, text="Head")
        head.prop(context.active_object.data, "layers", index=18, toggle=True, text="Ears")

        iklegs = col.row()
        iklegs.label(text="IK Legs:")
        iklegs.prop(context.active_object.data, "layers", index=20, toggle=True, text="Front")
        iklegs.prop(context.active_object.data, "layers", index=21, toggle=True, text="Back")

        fklegs = col.row()
        fklegs.label(text="FK Legs:")
        fklegs.prop(context.active_object.data, "layers", index=4, toggle=True, text="Front")
        fklegs.prop(context.active_object.data, "layers", index=5, toggle=True, text="Back")
        
        extra = col.row()
        extra.label(text="Extra:")
        extra.prop(context.active_object.data, "layers", index=2, toggle=True, text="Tail")
        extra.label(text="")
        
        bend = col.row()
        bend.label(text="Bend:")
        bend.prop(context.active_object.data, "layers", index=6, toggle=True, text="Front")
        bend.prop(context.active_object.data, "layers", index=7, toggle=True, text="Back")

class AlexVisib(bpy.types.Panel):
    bl_space_type = 'VIEW_3D'
    bl_region_type = 'UI'
    bl_label = "Alex Visibility"

    @classmethod
    def poll(self, context):
        if context.mode != 'POSE':
            return False
        try:
           ob = context.active_object
           return (ob.name == "Alex_rig" or ob.name == "Alex_proxy")
        except AttributeError:
           return 0

    def draw(self, context):
        layout = self.layout
        col = layout.column()
        row = col.row(align=True)
        
       
        
                      
        col = layout.column()
        row = col.row(align=True)
        row.prop(bpy.data.objects["Alex_Mesh"].modifiers["Mask_Head"], "show_viewport", text="Hide Head")
        row.prop(bpy.data.objects["Alex_Mesh"].modifiers["Mask_Head"], "show_render", text="")
        
        col = layout.column()
        row = col.row(align=True)
        row.prop(bpy.data.objects["Alex_Mesh"].modifiers["Mask_Neck"], "show_viewport", text="Hide Neck")
        row.prop(bpy.data.objects["Alex_Mesh"].modifiers["Mask_Neck"], "show_render", text="")
                
        col = layout.column()
        row = col.row(align=True)
        row.prop(bpy.data.objects["Alex_Mesh"].modifiers["Mask_Body"], "show_viewport", text="Hide Body")
        row.prop(bpy.data.objects["Alex_Mesh"].modifiers["Mask_Body"], "show_render", text="")
        
        col = layout.column()
        row = col.row(align=True)
        row.prop(bpy.data.objects["Alex_Mesh"].modifiers["Mask_LegsFront"], "show_viewport", text="Hide Front Legs")
        row.prop(bpy.data.objects["Alex_Mesh"].modifiers["Mask_LegsFront"], "show_render", text="")
        
        col = layout.column()
        row = col.row(align=True)
        row.prop(bpy.data.objects["Alex_Mesh"].modifiers["Mask_LegsBack"], "show_viewport", text="Hide Back Legs")
        row.prop(bpy.data.objects["Alex_Mesh"].modifiers["Mask_LegsBack"], "show_render", text="")
        
        col = layout.column()
        row = col.row(align=True)
        row.prop(bpy.data.objects["Alex_Mesh"].modifiers["Mask_Tail"], "show_viewport", text="Hide Tail")
        row.prop(bpy.data.objects["Alex_Mesh"].modifiers["Mask_Tail"], "show_render", text="")




def is_selected(context, names):
    try:
        for name in names:
            if context.active_pose_bone.name == name:
                return True
        for bone in context.selected_pose_bones:
            for name in names:
                if bone.name == name:
                    return True
    except AttributeError:
        pass
    return False




def register():
    bpy.utils.register_class(AlexProperties)
    bpy.utils.register_class(AlexLayers)
    bpy.utils.register_class(AlexVisib)
    


def unregister():
    bpy.utils.unregister_class(AlexProperties)
    bpy.utils.unregister_class(AlexLayers)
    bpy.utils.unregister_class(AlexVisib)
    

if __name__ == "__main__":
    register()
